@@ -10,7 +10,7 @@ class PredictIssue():
         from dataneuronalp.config_variables import API_TOKEN
 
         try:
-            response = (requests.post("http://20.212.37.37/prediction_API", headers={"x-access-token": API_TOKEN}, json={"apiToken": API_TOKEN, "workflow": workflow_id, "data": data})).text
+            response = (requests.post("http://20.212.37.37:4000/prediction_API", headers={"x-access-token": API_TOKEN}, json={"apiToken": API_TOKEN, "workflow": workflow_id, "data": data})).text
             
             if response == "Error: Authorization failed":
                 status = "FAILURE"
@@ -47,7 +47,7 @@ class PredictIssue():
 
         else:
             try:
-                task_status = (requests.get("http://20.212.37.37/prediction_results/"+task_id, headers={"x-access-token": API_TOKEN})).json()
+                task_status = (requests.get("http://20.212.37.37:4000/prediction_results/"+task_id, headers={"x-access-token": API_TOKEN})).json()
                 status = task_status["state"]
 
                 if status == "AUTHORIZATION FAILURE":
@@ -106,7 +106,7 @@ class PredictMultilabel():
         from dataneuronalp.config_variables import API_TOKEN
 
         try:
-            response = (requests.post("http://20.212.37.37/mlc_prediction_API", headers={"x-access-token": API_TOKEN}, json={"apiToken": API_TOKEN, "workflow": workflow_id, "data": data})).text
+            response = (requests.post("http://20.212.37.37:4000/mlc_prediction_API", headers={"x-access-token": API_TOKEN}, json={"apiToken": API_TOKEN, "workflow": workflow_id, "data": data})).text
             
             if response == "Error: Authorization failed":
                 status = "FAILURE"
@@ -143,7 +143,7 @@ class PredictMultilabel():
 
         else:
             try:
-                task_status = (requests.get("http://20.212.37.37/prediction_results/"+task_id, headers={"x-access-token": API_TOKEN})).json()
+                task_status = (requests.get("http://20.212.37.37:4000/prediction_results/"+task_id, headers={"x-access-token": API_TOKEN})).json()
                 status = task_status["state"]
 
                 if status == "AUTHORIZATION FAILURE":
